@@ -82,7 +82,7 @@ use smallvec::{Array, SmallVec};
 use wide::*;
 
 #[cfg(feature = "use_serde")]
-use core::marker::PhantomData;
+use core::{cmp, marker::PhantomData};
 #[cfg(feature = "use_serde")]
 use serde::{
     de::{DeserializeOwned, Deserializer, SeqAccess, Visitor},
@@ -1351,8 +1351,9 @@ where
         0
     };
 
-    let mut seq = s.serialize_seq(Some((x.len() - 1) * L + last_count))?;
-    for block in &x[0..x.len() - 1] {
+    let prefix_len = cmp::max(x.len(), 1) - 1;
+    let mut seq = s.serialize_seq(Some(prefix_len * L + last_count))?;
+    for block in &x[0..prefix_len] {
         for element in block.to_array().iter() {
             seq.serialize_element(element)?;
         }
